@@ -3,12 +3,12 @@
 from .api import (
     CMJVideoConfig,
     CMJVideoResult,
-    VideoConfig,
-    VideoResult,
+    DropJumpVideoConfig,
+    DropJumpVideoResult,
     process_cmj_video,
     process_cmj_videos_bulk,
-    process_video,
-    process_videos_bulk,
+    process_dropjump_video,
+    process_dropjump_videos_bulk,
 )
 from .cmj.kinematics import CMJMetrics
 from .dropjump.kinematics import DropJumpMetrics
@@ -17,10 +17,10 @@ __version__ = "0.1.0"
 
 __all__ = [
     # Drop jump API
-    "process_video",
-    "process_videos_bulk",
-    "VideoConfig",
-    "VideoResult",
+    "process_dropjump_video",
+    "process_dropjump_videos_bulk",
+    "DropJumpVideoConfig",
+    "DropJumpVideoResult",
     "DropJumpMetrics",
     # CMJ API
     "process_cmj_video",
