@@ -81,6 +81,100 @@ class PoseTracker:
         self.pose.close()
 
 
+def _add_head_segment(
+    segments: list,
+    weights: list,
+    visibilities: list,
+    landmarks: dict[str, tuple[float, float, float]],
+    vis_threshold: float,
+) -> None:
+    """Add head segment (8% body mass) if visible."""
+    if "nose" in landmarks:
+        x, y, vis = landmarks["nose"]
+        if vis > vis_threshold:
+            segments.append((x, y))
+            weights.append(0.08)
+            visibilities.append(vis)
+
+
+def _add_trunk_segment(
+    segments: list,
+    weights: list,
+    visibilities: list,
+    landmarks: dict[str, tuple[float, float, float]],
+    vis_threshold: float,
+) -> None:
+    """Add trunk segment (50% body mass) if visible."""
+    trunk_keys = ["left_shoulder", "right_shoulder", "left_hip", "right_hip"]
+    trunk_pos = [
+        (x, y, vis)
+        for key in trunk_keys
+        if key in landmarks
+        for x, y, vis in [landmarks[key]]
+        if vis > vis_threshold
+    ]
+    if len(trunk_pos) >= 2:
+        trunk_x = float(np.mean([p[0] for p in trunk_pos]))
+        trunk_y = float(np.mean([p[1] for p in trunk_pos]))
+        trunk_vis = float(np.mean([p[2] for p in trunk_pos]))
+        segments.append((trunk_x, trunk_y))
+        weights.append(0.50)
+        visibilities.append(trunk_vis)
+
+
+def _add_limb_segment(
+    segments: list,
+    weights: list,
+    visibilities: list,
+    landmarks: dict[str, tuple[float, float, float]],
+    side: str,
+    proximal_key: str,
+    distal_key: str,
+    segment_weight: float,
+    vis_threshold: float,
+) -> None:
+    """Add a limb segment (thigh or lower leg) if both endpoints visible."""
+    prox_full = f"{side}_{proximal_key}"
+    dist_full = f"{side}_{distal_key}"
+
+    if prox_full in landmarks and dist_full in landmarks:
+        px, py, pvis = landmarks[prox_full]
+        dx, dy, dvis = landmarks[dist_full]
+        if pvis > vis_threshold and dvis > vis_threshold:
+            seg_x = (px + dx) / 2
+            seg_y = (py + dy) / 2
+            seg_vis = (pvis + dvis) / 2
+            segments.append((seg_x, seg_y))
+            weights.append(segment_weight)
+            visibilities.append(seg_vis)
+
+
+def _add_foot_segment(
+    segments: list,
+    weights: list,
+    visibilities: list,
+    landmarks: dict[str, tuple[float, float, float]],
+    side: str,
+    vis_threshold: float,
+) -> None:
+    """Add foot segment (1.5% body mass per foot) if visible."""
+    foot_keys = [f"{side}_ankle", f"{side}_heel", f"{side}_foot_index"]
+    foot_pos = [
+        (x, y, vis)
+        for key in foot_keys
+        if key in landmarks
+        for x, y, vis in [landmarks[key]]
+        if vis > vis_threshold
+    ]
+    if foot_pos:
+        foot_x = float(np.mean([p[0] for p in foot_pos]))
+        foot_y = float(np.mean([p[1] for p in foot_pos]))
+        foot_vis = float(np.mean([p[2] for p in foot_pos]))
+        segments.append((foot_x, foot_y))
+        weights.append(0.015)
+        visibilities.append(foot_vis)
+
+
 def compute_center_of_mass(
     landmarks: dict[str, tuple[float, float, float]],
     visibility_threshold: float = 0.5,
@@ -106,114 +200,59 @@ def compute_center_of_mass(
         (x, y, visibility) tuple for estimated CoM position
         visibility = average visibility of all segments used
     """
-    # Define segment representatives and their weights (as fraction of body mass)
-    # Each segment uses midpoint or average of its bounding landmarks
-    segments = []
-    segment_weights = []
-    visibilities = []
+    segments: list = []
+    weights: list = []
+    visibilities: list = []
 
-    # Head segment: 8% (use nose as proxy)
-    if "nose" in landmarks:
-        x, y, vis = landmarks["nose"]
-        if vis > visibility_threshold:
-            segments.append((x, y))
-            segment_weights.append(0.08)
-            visibilities.append(vis)
+    # Add body segments
+    _add_head_segment(segments, weights, visibilities, landmarks, visibility_threshold)
+    _add_trunk_segment(segments, weights, visibilities, landmarks, visibility_threshold)
 
-    # Trunk segment: 50% (midpoint between shoulders and hips)
-    trunk_landmarks = ["left_shoulder", "right_shoulder", "left_hip", "right_hip"]
-    trunk_positions = [
-        (x, y, vis)
-        for key in trunk_landmarks
-        if key in landmarks
-        for x, y, vis in [landmarks[key]]
-        if vis > visibility_threshold
-    ]
-    if len(trunk_positions) >= 2:
-        trunk_x = float(np.mean([pos[0] for pos in trunk_positions]))
-        trunk_y = float(np.mean([pos[1] for pos in trunk_positions]))
-        trunk_vis = float(np.mean([pos[2] for pos in trunk_positions]))
-        segments.append((trunk_x, trunk_y))
-        segment_weights.append(0.50)
-        visibilities.append(trunk_vis)
-
-    # Thigh segment: 20% total (midpoint hip to knee for each leg)
+    # Add bilateral limb segments
     for side in ["left", "right"]:
-        hip_key = f"{side}_hip"
-        knee_key = f"{side}_knee"
-        if hip_key in landmarks and knee_key in landmarks:
-            hip_x, hip_y, hip_vis = landmarks[hip_key]
-            knee_x, knee_y, knee_vis = landmarks[knee_key]
-            if hip_vis > visibility_threshold and knee_vis > visibility_threshold:
-                thigh_x = (hip_x + knee_x) / 2
-                thigh_y = (hip_y + knee_y) / 2
-                thigh_vis = (hip_vis + knee_vis) / 2
-                segments.append((thigh_x, thigh_y))
-                segment_weights.append(0.10)  # 10% per leg
-                visibilities.append(thigh_vis)
+        _add_limb_segment(
+            segments,
+            weights,
+            visibilities,
+            landmarks,
+            side,
+            "hip",
+            "knee",
+            0.10,
+            visibility_threshold,
+        )
+        _add_limb_segment(
+            segments,
+            weights,
+            visibilities,
+            landmarks,
+            side,
+            "knee",
+            "ankle",
+            0.05,
+            visibility_threshold,
+        )
+        _add_foot_segment(
+            segments, weights, visibilities, landmarks, side, visibility_threshold
+        )
 
-    # Lower leg segment: 10% total (midpoint knee to ankle for each leg)
-    for side in ["left", "right"]:
-        knee_key = f"{side}_knee"
-        ankle_key = f"{side}_ankle"
-        if knee_key in landmarks and ankle_key in landmarks:
-            knee_x, knee_y, knee_vis = landmarks[knee_key]
-            ankle_x, ankle_y, ankle_vis = landmarks[ankle_key]
-            if knee_vis > visibility_threshold and ankle_vis > visibility_threshold:
-                leg_x = (knee_x + ankle_x) / 2
-                leg_y = (knee_y + ankle_y) / 2
-                leg_vis = (knee_vis + ankle_vis) / 2
-                segments.append((leg_x, leg_y))
-                segment_weights.append(0.05)  # 5% per leg
-                visibilities.append(leg_vis)
-
-    # Foot segment: 3% total (average of ankle, heel, foot_index)
-    for side in ["left", "right"]:
-        foot_keys = [f"{side}_ankle", f"{side}_heel", f"{side}_foot_index"]
-        foot_positions = [
-            (x, y, vis)
-            for key in foot_keys
-            if key in landmarks
-            for x, y, vis in [landmarks[key]]
-            if vis > visibility_threshold
-        ]
-        if foot_positions:
-            foot_x = float(np.mean([pos[0] for pos in foot_positions]))
-            foot_y = float(np.mean([pos[1] for pos in foot_positions]))
-            foot_vis = float(np.mean([pos[2] for pos in foot_positions]))
-            segments.append((foot_x, foot_y))
-            segment_weights.append(0.015)  # 1.5% per foot
-            visibilities.append(foot_vis)
-
-    # If no segments found, fall back to hip average
+    # Fallback if no segments found
     if not segments:
         if "left_hip" in landmarks and "right_hip" in landmarks:
             lh_x, lh_y, lh_vis = landmarks["left_hip"]
             rh_x, rh_y, rh_vis = landmarks["right_hip"]
-            return (
-                (lh_x + rh_x) / 2,
-                (lh_y + rh_y) / 2,
-                (lh_vis + rh_vis) / 2,
-            )
-        # Ultimate fallback: center of frame
+            return ((lh_x + rh_x) / 2, (lh_y + rh_y) / 2, (lh_vis + rh_vis) / 2)
         return (0.5, 0.5, 0.0)
 
-    # Normalize weights to sum to 1.0
-    total_weight = sum(segment_weights)
-    normalized_weights = [w / total_weight for w in segment_weights]
+    # Normalize weights and compute weighted average
+    total_weight = sum(weights)
+    normalized_weights = [w / total_weight for w in weights]
 
-    # Compute weighted average of segment positions
     com_x = float(
-        sum(
-            pos[0] * weight
-            for pos, weight in zip(segments, normalized_weights, strict=True)
-        )
+        sum(p[0] * w for p, w in zip(segments, normalized_weights, strict=True))
     )
     com_y = float(
-        sum(
-            pos[1] * weight
-            for pos, weight in zip(segments, normalized_weights, strict=True)
-        )
+        sum(p[1] * w for p, w in zip(segments, normalized_weights, strict=True))
     )
     com_visibility = float(np.mean(visibilities)) if visibilities else 0.0
 
